@@ -1,23 +1,13 @@
 package Term::GentooFunctions;
 
-require 5.008;
-
 use strict;
-
-BEGIN {
-    eval "use Term::Size;";               my $old = $@;
-    eval "use Term::Size::Win32" if $old; my $new = $@;
-    die $old if $old and $new;
-    die $new if $new;
-}
-
 use Exporter;
+use Term::Size;
 use Term::ANSIColor qw(:constants);
 use Term::ANSIScreen qw(:cursor);
 
-use version;
-our $VERSION = version->new("1.2.0")->numify;
-our @EXPORT_OK = qw(einfo eerror ewarn ebegin eend eindent eoutdent einfon edie);
+our $VERSION = "1.01";
+our @EXPORT_OK = qw(einfo eerror ewarn ebegin eend eindent eoutdent einfon);
 our %EXPORT_TAGS = (all=>[@EXPORT_OK]);
 
 use base qw(Exporter);
@@ -32,12 +22,6 @@ BEGIN {
 
 1;
 
-sub edie {
-    &eerror($_) for @_;
-    &eend(0);
-    exit 1;
-}
-
 sub einfon {
     my $msg = &wash(shift);
 
@@ -61,7 +45,7 @@ sub wash {
     my $msg = shift;
        $msg =~ s/[\r\n]//sg;
        $msg =~ s/^\s+//s;
-     # $msg =~ s/\s+$//s;  # NOTE: do not wash this off.  When we call einfon() we expect to keep trailing spaces.!!
+       $msg =~ s/\s+$//s;
 
     return "$ENV{RC_INDENTATION} $msg";
 }
@@ -90,10 +74,7 @@ sub ebegin {
 
 sub eend {
     my $res = (@_>0 ? shift : $_);
-    my ($columns, $rows) = eval 'Term::Size::chars *STDOUT{IO}';
-       ($columns, $rows) = eval 'Term::Size::Win32::chars *STDOUT{IO}' if $@;
-
-    die "couldn't find a term size function to use" if $@;
+    my ($columns, $rows) = Term::Size::chars *STDOUT{IO};
 
     print up(1), right($columns - 6), BOLD, BLUE, "[ ", 
         ($res ?  GREEN."ok" : RED."!!"), 
@@ -157,15 +138,25 @@ before you fork to perl.  Also, T::GF won't be able to modify the indent level i
 
 =head1 AUTHOR
 
-Paul Miller <jettero@cpan.org>
+Please contact me with ANY suggestions, no matter how pedantic.
 
-I am using this software in my own projects...  If you find bugs, please
-please please let me know. :) Actually, let me know if you find it handy at
-all.  Half the fun of releasing this stuff is knowing that people use it.
+Jettero Heller <japh@voltar-confed.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007 Paul Miller -- LGPL [attached]
+GPL!  I included a gpl.txt for your reading enjoyment.
+
+Though, additionally, I will say that I'll be tickled if you were to
+include this package in any commercial endeavor.  Also, any thoughts to
+the effect that using this module will somehow make your commercial
+package GPL should be washed away.
+
+I hereby release you from any such silly conditions.
+
+This package and any modifications you make to it must remain GPL.  Any
+programs you (or your company) write shall remain yours (and under
+whatever copyright you choose) even if you use this package's intended
+and/or exported interfaces in them.
 
 =head1 SEE ALSO
 
